from distutils.core import setup

setup(
	name = 'LeanTurenester',
	version = '1.0.0',
	py_modules = ['LeanTurenester'],
	author = 'taewankim',
	author_email = "kingwan1101@gmail.com",
	url = 'http://wani111.github.io/web1',
	description = 'A simple printer of nested lists',
)